==> picketlink-console-extensions-1.0.3.Final-sources.jar: org/picketlink/as/console/client/i18n/PicketLinkUIConstants.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.picketlink.as.console.client.i18n;

import com.google.gwt.i18n.client.Constants;


/**
 * @author <a href="mailto:psilva@redhat.com">Pedro Silva</a>
 * @since Mar 30, 2012
 */
public interface PicketLinkUIConstants extends Constants {

    String common_label_federation();
    String common_label_identityProvider();
    String common_label_serviceProvider();
    String common_label_trustDomain();
    String common_label_alias();
    String common_label_URL();
    String common_label_supportsSignatures();
    String common_label_postBinding();
    String common_label_trustedDomains();
    String common_label_domainName();
    String common_label_federationAlias();
    String common_label_identityURL();
    String common_label_key_store();
    String common_label_endpoint();
    String common_label_securityTokenService();
    String subsys_picketlink_identity_provider_desc();
    String subsys_picketlink_service_provider_desc();
    String subsys_picketlink_security_token_service_desc();
    
}

==> picketlink-console-extensions-2.0.5.Final-sources.jar: org/picketlink/as/console/client/i18n/PicketLinkUIConstants.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.picketlink.as.console.client.i18n;

import com.google.gwt.i18n.client.Constants;


/**
 * @author <a href="mailto:psilva@redhat.com">Pedro Silva</a>
 * @since Mar 30, 2012
 */
public interface PicketLinkUIConstants extends Constants {

    String common_label_federation();
    String common_label_identityProvider();
    String common_label_serviceProvider();
    String common_label_trustDomain();
    String common_label_name();
    String common_label_URL();
    String common_label_supportsSignatures();
    String common_label_postBinding();
    String common_label_trustedDomains();
    String common_label_domainName();
    String common_label_federationName();
    String common_label_identityURL();
    String common_label_key_store();
    String common_label_endpoint();
    String common_label_securityTokenService();
    String subsys_picketlink_identity_provider_desc();
    String subsys_picketlink_service_provider_desc();
    String subsys_picketlink_security_token_service_desc();
    String subsys_picketlink_key_store_desc();
    String common_label_key();
    String common_label_key_host();
    String common_label_key_alias();
}
